@@ -33,7 +33,7 @@ $fn = cms_join_path(__DIR__,'function.social.php'); require_once($fn);
 class SEOBoost extends \CMSModule {
 
     const USE_PERM = 'use_seoboost';
-    const MODULE_VERSION = '1.5.1';
+    const MODULE_VERSION = '1.6';
 
     const BULK_EDIT_CORE_FIELDS = [
             'core_content_name',     // these are in the content table
@@ -133,6 +133,14 @@ class SEOBoost extends \CMSModule {
         $this->SetParameterType('debug', CLEAN_INT);
         $this->SetParameterType('type',CLEAN_STRING);
 
+        // the dynamic routes below replaces the static routes used previously
+        // the static routes caused issues when a site was installed on a subfolder 
+        # start - mod by Jo Morg 
+        $this->RegisterRoute('/sitemap-*[0-9a-zA-Z-_]*\.xml/', array('action' => 'sitemap'));
+        $this->RegisterRoute('/robots.txt/', array('action' => 'sitemap'));
+        $this->RegisterRoute('/feeds-news.rss/', array('action' => 'sitemap'));
+        # end - mod by Jo Morg
+
         // set Hook to generate $pageVars smarty var before each page rendered
         \CMSMS\HookManager::add_hook('Core::ContentPreRender','SEOBoost::SetPageVarsHook');
 
@@ -295,26 +303,26 @@ class SEOBoost extends \CMSModule {
    }
 
 
+// removed 
+//    public function CreateStaticRoutes() {
+//    //***********************************************************************************************
+//    //    set & forget all possible static routes
+//    //***********************************************************************************************
+//     //   cms_route_manager::del_static('',$this->GetName());  // remove all modules routes
 
-   public function CreateStaticRoutes() {
-   //***********************************************************************************************
-   //    set & forget all possible static routes
-   //***********************************************************************************************
-      cms_route_manager::del_static('',$this->GetName());  // remove all modules routes
-
-      $contentOps = \ContentOperations::get_instance();
-      $defaultPageId = $contentOps->GetDefaultContent(); // need any valid page id
-      $defaults = array( 'action'=>'sitemap', 'returnid'=>$defaultPageId);
-      // xml sitemaps
-      $route = new CmsRoute( '/^sitemap-*[0-9a-zA-Z-_]*\.xml$/', 'SEOBoost', $defaults );
-      cms_route_manager::add_static($route);
-      // robots.txt
-      $route = new CmsRoute( '/^robots.txt$/', 'SEOBoost', $defaults );
-      cms_route_manager::add_static($route);
-      // feed-news.rss
-      $route = new CmsRoute( '/^feeds-news.rss$/', 'SEOBoost', $defaults );
-      cms_route_manager::add_static($route);
-   }
+//     //   $contentOps = \ContentOperations::get_instance();
+//     //   $defaultPageId = $contentOps->GetDefaultContent(); // need any valid page id
+//     //   $defaults = array( 'action'=>'sitemap', 'returnid'=>$defaultPageId);
+//     //   // xml sitemaps
+//     //   $route = new CmsRoute( '/^sitemap-*[0-9a-zA-Z-_]*\.xml$/', 'SEOBoost', $defaults );
+//     //   cms_route_manager::add_static($route);
+//     //   // robots.txt
+//     //   $route = new CmsRoute( '/^robots.txt$/', 'SEOBoost', $defaults );
+//     //   cms_route_manager::add_static($route);
+//     //   // feed-news.rss
+//     //   $route = new CmsRoute( '/^feeds-news.rss$/', 'SEOBoost', $defaults );
+//     //   cms_route_manager::add_static($route);
+//    }
 
 
 
