@@ -317,6 +317,13 @@ EOD;
 $lang['changelog'] = <<<'EOD'
 
 
+<h3>Version 1.6</h3>
+<ul>
+    <li>Changed sitemaps to use dynamic routes instead of static routes to improve compatibility with sites installed in subfolders.</li>
+</ul>
+<br>
+
+
 <h3>Version 1.5.1</h3>
 <ul>
     <li>Bug Fix - LISE instances with the same name as another module e.g. LISENews are now listed under XML Sitemaps</li>
